Core/Zmq: reduced thread sleep time from 50ms down to 1ms

This commit is contained in:
Ovahlord committed 2025-02-28 20:41:56 +01:00
1 parent 0927c5af40
commit 3ef766851a
1 file changed
+1 -1
+1 -1
View File
@@ -56,7 +56,7 @@ void ZmqMux::Run()
{ {
for (;;) for (;;)
{ {
std::this_thread::sleep_for(std::chrono::milliseconds(50)); std::this_thread::sleep_for(std::chrono::milliseconds(1));
if (!_poller->poll()) if (!_poller->poll())
break; break;